package com.order.controller.business;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.BsOrderCoupon;
import com.hfkj.model.ResponseData;
import com.hfkj.model.order.OrderCouponModel;
import com.hfkj.service.coupon.BsOrderCouponNoService;
import com.hfkj.service.coupon.BsOrderCouponService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @className: OrderCouponController
 * @author: HuRui
 * @date: 2024/5/11
 **/
@Controller
@RequestMapping(value="/coupon")
@Api(value="卡券订单业务")
public class OrderCouponController {
    Logger log = LoggerFactory.getLogger(OrderCouponController.class);

    @Resource
    private BsOrderCouponService orderCouponService;
    @Resource
    private BsOrderCouponNoService orderCouponNoService;

    @RequestMapping(value="/queryCouNo",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询卡密")
    public ResponseData queryCouNo(@RequestParam(value = "orderChildNo" , required = true) String orderChildNo) {
        try {
            // 卡券订单
            BsOrderCoupon orderCoupon = orderCouponService.getDetailByChildOrderNo(orderChildNo);
            if (orderCoupon == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的卡券订单");
            }

            return ResponseMsgUtil.success(orderCouponNoService.getListByCouponOrderId(orderCoupon.getId()));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryDetail",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询交易订单详情")
    public ResponseData queryDetail(@RequestParam(value = "orderChildNo" , required = true) String orderChildNo) {
        try {
            Map<String,Object> param = new HashMap<>();
            param.put("order", orderCouponService.getDetailByChildOrderNo(orderChildNo));

            Map<String,Object> goodsParam = new HashMap<>();
            goodsParam.put("orderChildNo", orderChildNo);
            param.put("goods", orderCouponService.getOrderList(goodsParam));

            return ResponseMsgUtil.success(param);

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询交易订单列表")
    public ResponseData queryList(@RequestParam(value = "orderNo" , required = false) String orderNo,
                                  @RequestParam(value = "userPhone" , required = false) String userPhone,
                                  @RequestParam(value = "tradeStatus" , required = false) Integer tradeStatus,
                                  @RequestParam(value = "goodsName" , required = false) String goodsName,
                                  @RequestParam(value = "payType" , required = false) Integer payType,
                                  @RequestParam(value = "channelOrderNo" , required = false) String channelOrderNo,
                                  @RequestParam(value = "couNo" , required = false) String couNo,
                                  @RequestParam(value = "couStatus" , required = false) Integer couStatus,
                                  @RequestParam(value = "createTimeS" , required = false) Long createTimeS,
                                  @RequestParam(value = "createTimeE" , required = false) Long createTimeE,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            Map<String,Object> param = new HashMap<>();
            param.put("orderNo", orderNo);
            param.put("userPhone", userPhone);
            param.put("tradeStatus", tradeStatus);
            param.put("goodsName", goodsName);
            param.put("payType", payType);
            param.put("channelOrderNo", channelOrderNo);
            param.put("couNo", couNo);
            param.put("couStatus", couStatus);
            param.put("createTimeS", createTimeS);
            param.put("createTimeE", createTimeE);

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(orderCouponService.getOrderList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/export",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询交易订单列表")
    public ResponseData export(@RequestParam(value = "orderNo" , required = false) String orderNo,
                                  @RequestParam(value = "userPhone" , required = false) String userPhone,
                                  @RequestParam(value = "tradeStatus" , required = false) Integer tradeStatus,
                                  @RequestParam(value = "goodsName" , required = false) String goodsName,
                                  @RequestParam(value = "payType" , required = false) Integer payType,
                                  @RequestParam(value = "channelOrderNo" , required = false) String channelOrderNo,
                                  @RequestParam(value = "couNo" , required = false) String couNo,
                                  @RequestParam(value = "couStatus" , required = false) Integer couStatus,
                                  @RequestParam(value = "createTimeS" , required = false) Long createTimeS,
                                  @RequestParam(value = "createTimeE" , required = false) Long createTimeE) {
        try {
            Map<String,Object> param = new HashMap<>();
            param.put("orderNo", orderNo);
            param.put("userPhone", userPhone);
            param.put("tradeStatus", tradeStatus);
            param.put("goodsName", goodsName);
            param.put("payType", payType);
            param.put("channelOrderNo", channelOrderNo);
            param.put("couNo", couNo);
            param.put("couStatus", couStatus);
            param.put("createTimeS", createTimeS);
            param.put("createTimeE", createTimeE);
            List<OrderCouponModel> orderList = orderCouponService.getOrderList(param);


            return ResponseMsgUtil.success(orderList);

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }





}
